@@ -1,4 +1,4 @@
-﻿#ifndef CUSTOMDIALOG_H
+#ifndef CUSTOMDIALOG_H
 #define CUSTOMDIALOG_H
 
 #include <QDialog>
@@ -7,6 +7,9 @@
 #include <QSlider>
 
 #include "ui.h"
+
+extern QStringList fnames;
+
 class CustomDialog : public QDialog
 {
     Q_OBJECT
@@ -19,11 +22,13 @@ class CustomDialog : public QDialog
     QSpinBox *algono, *seedno, *shiftno;
     QLabel *img;
     QSlider *seedslider, *algoslider, *shiftslider;
+    unsigned char newColors[][3];
   private slots:
     void chooseInputFile();
+    void chooseInputFiles();
     void chooseOutputFile();
     void updateVisualiser();
-
+    void colorPicker();
   public:
     CustomDialog(struct uih_context *uih, const menuitem *item,
                  const menudialog *dialog, QWidget *parent = 0);
