@@ -1,11 +1,27 @@
 ﻿#include <QtWidgets>
-
 #include "config.h"
 #include "filter.h"
 #include "grlib.h"
 #include "xio.h"
 #include "misc-f.h"
 
+void rgbtohex (int r, int g, int b, char color[6]) {
+    QColor rgb(r, g, b);
+    QString hex = rgb.name();
+    hex.remove(0, 1);
+    strcpy(color, hex.toStdString().c_str());
+}
+
+void hextorgb (char *hexcolor, rgb_t color) {
+    QString hexa = hexcolor;
+    hexa.push_front('#');
+    QColor hex(hexa);
+    QColor rgb = hex.toRgb();
+    color[0] = rgb.red();
+    color[1] = rgb.green();
+    color[2] = rgb.blue();
+}
+
 static QFont getFont(void *font) {
     if (font)
         return *reinterpret_cast<QFont *>(font);
@@ -70,7 +86,8 @@ const char *writepng(xio_constpath filename, const struct image *image, xio_file
         QString xpf_chunk = xio_getstring(xpf_data);
         qimage->setText("Metadata", xpf_chunk);
     }
-    qimage->save(filename);
+    if(!qimage->save(filename))
+        return "Invalid file extension";
     return NULL;
 }
 
